==> mtcmedia-revolut-payment-provider-1.0.4-2a190b.tar: src/Support/Proxy.php <==
<?php
    namespace Mtcmedia\RevolutPaymentProvider\Support;

    use GuzzleHttp\Client;
    use GuzzleHttp\Exception\GuzzleException;
    use Illuminate\Support\Facades\Log;
    use Illuminate\Support\Facades\Http;
    use Illuminate\Http\Request;
    use Illuminate\Routing\Controller as BaseController;

    class Proxy extends BaseController
    {

        private $baseUrl;
        public $headers;

        public function __construct(
            public Request $request
        )
        {

            $this->headers = [
                'Authorization'  => "Bearer ".env("REVOLUT_API_KEY"),
                'Content-Type'  => 'application/json',
                'Revolut-Api-Version' => "2024-09-01"
            ];
        }

        public function makeRevolutApiRequest($endpoint)
        {
            $queryString = $this->request->getQueryString();

            if ($queryString) {
                $endpoint .= '?' . $queryString;
            }

            // Strip '/revolut-api' prefix if present
            $endpoint = preg_replace('#^/?revolut-api#', '', $endpoint);


            $environment = env("REVOLUT_TEST_MODE");

            $this->baseUrl = $environment === false
                ? 'https://api.revolut.com'
                : 'https://sandbox-merchant.revolut.com';




            $url = rtrim($this->baseUrl, '/') . '/' . ltrim($endpoint, '/');
            $httpRequest = Http::withHeaders($this->headers);
            // Add body for certain HTTP methods
            if (in_array($this->request->method(), ['POST', 'PUT', 'PATCH', 'DELETE'])) {
                $httpRequest = $httpRequest->withBody($this->request->getContent(), 'application/json');
            }

            try{
                $response = $httpRequest->withOptions([
                    'verify' => false,
                ])
                    ->send($this->request->method(), $url)
                    ->throw()
                ;
                return $response->collect();

            }catch (\Exception $e){
                Log::error('Revolut API request failed', [
                    'message' => $e->getMessage(),
                    'trace' => $e->getTraceAsString(),
                ]);
                abort(500, "Revolut API request failed: " . $e->getMessage());
            }
        }

        public function proxyRevolutApiRequest($endpoint)
        {

            $resonse = $this->makeRevolutApiRequest($endpoint);

            return response($resonse->toJson(),200)
                ->header('Content-Type', 'application/json');
        }

    }

==> mtcmedia-revolut-payment-provider-1.0.8-2b2b81.tar: src/Support/Proxy.php <==
<?php
    namespace Mtc\RevolutPaymentProvider\Support;

    use GuzzleHttp\Client;
    use GuzzleHttp\Exception\GuzzleException;
    use Illuminate\Support\Facades\Log;
    use Illuminate\Support\Facades\Http;
    use Illuminate\Http\Request;
    use Illuminate\Routing\Controller as BaseController;

    class Proxy extends BaseController
    {

        private $baseUrl;
        public $headers;

        public function __construct(
            public Request $request
        )
        {

            $this->headers = [
                'Authorization'  => "Bearer ".config('revolut.api_key'),
                'Content-Type'  => 'application/json',
                'Revolut-Api-Version' => "2024-09-01"
            ];
            $this->baseUrl = config("revolut.api_url");

        }

        public function makeRevolutApiRequest($endpoint)
        {
            $queryString = $this->request->getQueryString();

            if ($queryString) {
                $endpoint .= '?' . $queryString;
            }

            // Strip '/revolut-api' prefix if present
            $endpoint = preg_replace('#^/?revolut-api#', '', $endpoint);

            $url = rtrim($this->baseUrl, '/') . '/' . ltrim($endpoint, '/');
            $httpRequest = Http::withHeaders($this->headers);
            // Add body for certain HTTP methods
            if (in_array($this->request->method(), ['POST', 'PUT', 'PATCH', 'DELETE'])) {
                $httpRequest = $httpRequest->withBody($this->request->getContent(), 'application/json');
            }

            try{
                $response = $httpRequest->withOptions([
                    'verify' => false,
                ])
                    ->send($this->request->method(), $url)
                    ->throw()
                ;
                return $response->collect();

            }catch (\Exception $e){
                Log::error('Revolut API request failed', [
                    'message' => $e->getMessage(),
                    'trace' => $e->getTraceAsString(),
                ]);
                abort(500, "Revolut API request failed: " . $e->getMessage());
            }
        }

        public function proxyRevolutApiRequest($endpoint)
        {


            $resonse = $this->makeRevolutApiRequest($endpoint);

            return response($resonse->toJson(),200)
                ->header('Content-Type', 'application/json');
        }

    }
